<?php

namespace Drupal\views_save_search_filter\Controller;

use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\ReplaceCommand;
use Drupal\Core\Controller\ControllerBase;

/**
 * Returns responses for views_save_search_filter routes.
 */
class ViewsSaveSearchFilterController extends ControllerBase {

  /**
   * Get the list of saved views filter by logged in user id and current page view id.
   */
  public function getSaveFilters() {
    $titles = $this->fetchAndPrepareSavedSearchLIst();
    return [
      '#markup' => '<Ul class="filterlist">' . $titles . '</UL>',
    ];
  }

  /**
   * Fetched the saved search list.
   */
  public function fetchAndPrepareSavedSearchLIst() {
    $view_id = $this->getViewId();
    $user_id = \Drupal::currentUser()->id();
    $connection = \Drupal::service('database');
    $query = $connection->select('views_save_search_filter', 'hsf')
      ->condition('hsf.user_id', $user_id, '=')
      ->condition('hsf.view_id', $view_id, '=')
      ->fields('hsf', ['id', 'filter_title', 'filter_url', 'view_id'])
      ->range(0, 10);
    $result = $query->execute();
    $titles = "";
    foreach ($result as $record) {
      $titles .= "<li>
        <a target='_blank' href='" . $record->filter_url . "'>" . $record->filter_title . "</a> | 
        <a title='Delete' data-dialog-options='{&quot;width&quot;:400}' data-dialog-type='modal' class='use-ajax' href='/views-save-search-filter/delete-save-filters/" . $record->id . "' onclick='return confirm(\"Are you sure you want to delete this item?\");'><i class='fa fa-trash-o fa-fw'></i>Delete</a>
        </li>";
    }
    if ($titles == "") {
      $titles .= "No item is saved yet!";
    }
    return $titles;
  }

  /**
   * Delete the saved filters by filter id.
   */
  public function deleteSaveFilters(int $filter_id) {
    if (!empty($filter_id)) {
      $user_id = \Drupal::currentUser()->id();
      $connection = \Drupal::service('database');
      $query = $connection->delete('views_save_search_filter')
        ->condition('user_id', $user_id, '=')
        ->condition('id', $filter_id, '=');
      $query->execute();

      $response = new AjaxResponse();
      $selector = '.filterlist';
      $content = $this->getSaveFilters();
      $settings = []; /*An array of JavaScript settings to be passed to any attached behaviors.*/
      $response->addCommand(new ReplaceCommand($selector, $content, $settings));
      return $response;
    }
  }

  /**
   * Get the view or page URL to store the save search against it.
   */
  public function getViewId() {
    $path = $_SERVER['HTTP_REFERER'];
    $req_uri_with_noparam = strtok($path, '?');
    /*
    $view_id = explode('/', $req_uri_with_noparam);
    $count_arr = count($view_id);
    if($count_arr > 4) {
    $view_id = $view_id[4];
    } else {
    $view_id = $view_id[3];
    }
    $view_id = str_replace("-", "_", $view_id);
    return $view_id;
     */
    return $req_uri_with_noparam;
  }

}
